Bug 1253341 - Run duplicate Talos jobs in AWS for Linux (ubuntu64_vm_lnx_large). r?rail draft production
authorJoel Maher <jmaher@mozilla.com>
Thu, 14 Apr 2016 12:10:58 -0400
branchproduction
changeset 14101 8b0353739954eab4bf9bfd9c78102840e731c70e
parent 14100 b528ba46237a06d91b782a004ec01f9357ba351d
push id56
push userjmaher@mozilla.com
push dateThu, 14 Apr 2016 16:11:08 +0000
reviewersrail
bugs1253341
Bug 1253341 - Run duplicate Talos jobs in AWS for Linux (ubuntu64_vm_lnx_large). r?rail MozReview-Commit-ID: 43YRbd13uK2
mozilla-tests/config.py
--- a/mozilla-tests/config.py
+++ b/mozilla-tests/config.py
@@ -3154,24 +3154,24 @@ for branch in set(BRANCHES.keys()) - set
     for platform in ('win32', 'win64'):
         if platform not in BRANCHES[branch]['platforms']:
             continue
         if nested_haskey(BRANCHES[branch]['platforms'], platform, 'win7-ix'):
             del BRANCHES[branch]['platforms'][platform]['win7-ix']
 
 # Bug 1253341 - run talos jobs on AWS
 for branch in ('try',):
-    BRANCHES[branch]['platforms']['linux64']['talos_slave_platforms'] = ['ubuntu64_hw', 'ubuntu64_vm_large']
-    # Add ubuntu64_vm to the talos suites
+    BRANCHES[branch]['platforms']['linux64']['talos_slave_platforms'] = ['ubuntu64_hw', 'ubuntu64_vm_lnx_large']
+    # Add ubuntu64_vm_lnx_large to the talos suites
     for test, test_config in BRANCHES[branch].items():
         if not test.endswith('_tests'):
             continue
         tests, merge, extra, platforms = test_config
-        if 'ubuntu64_hw' in platforms and 'ubuntu64_vm_large' not in platforms:
-            platforms = platforms + ['ubuntu64_vm_large']
+        if 'ubuntu64_hw' in platforms and 'ubuntu64_vm_lnx_large' not in platforms:
+            platforms = platforms + ['ubuntu64_vm_lnx_large']
             BRANCHES[branch][test] = (tests, merge, extra, platforms)
 
 if __name__ == "__main__":
     import sys
     import pprint
 
     args = sys.argv[1:]